\name{rhierMnlRwMixture}
\alias{rhierMnlRwMixture}
\concept{bayes}
\concept{MCMC}
\concept{Multinomial Logit}
\concept{mixture of normals}
\concept{normal mixture}
\concept{heterogeneity}
\concept{hierarchical models}

\title{ MCMC Algorithm for Hierarchical Multinomial Logit with Mixture of Normals Heterogeneity}
\description{
  \code{rhierMnlRwMixture} is a MCMC algorithm for a hierarchical multinomial logit with a mixture of normals 
  heterogeneity distribution.  This is a hybrid Gibbs Sampler with a RW Metropolis step for the MNL 
  coefficients for each panel unit.
}
\usage{
rhierMnlRwMixture(Data, Prior, Mcmc, output)
}
\arguments{
  \item{Data}{ list(p,lgtdata,Z) ( Z is optional) }
  \item{Prior}{ list(a,deltabar,Ad,mubar,Amu,nu,V,ncomp) (all but ncomp are optional)}
  \item{Mcmc}{ list(s,w,R,keep,chains) (R required)}
  \item{output}{ binary output format.} 
}
\details{
  Model: \cr
  \eqn{y_i} \eqn{\sim}{~} \eqn{MNL(X_i,beta_i)}.  i=1,\ldots, length(lgtdata). \eqn{theta_i} is nvar x 1.

  \eqn{beta_i}= ZDelta[i,] + \eqn{u_i}. \cr
  Note: here ZDelta refers to Z\%*\%D, ZDelta[i,] is ith row of this product.\cr
  Delta is an nz x nvar array. 

  \eqn{u_i} \eqn{\sim}{~} \eqn{N(mu_{ind},Sigma_{ind})}. \eqn{ind} \eqn{\sim}{~} multinomial(pvec). \cr

  Priors: \cr
  \eqn{pvec} \eqn{\sim}{~} dirichlet (a)\cr
  \eqn{delta= vec(Delta)} \eqn{\sim}{~} \eqn{N(deltabar,A_d^{-1})}\cr
  \eqn{mu_j} \eqn{\sim}{~} \eqn{N(mubar,Sigma_j (x) Amu^{-1})}\cr
  \eqn{Sigma_j} \eqn{\sim}{~} IW(nu,V) \cr

  Lists contain:
  \itemize{
    \item{\code{p}}{ p is number of choice alternatives}
    \item{\code{lgtdata}}{list of lists with each cross-section unit MNL data}
    \item{\code{lgtdata[[i]]$y}}{ \eqn{n_i} vector of multinomial outcomes (1,\ldots,m)}
    \item{\code{lgtdata[[i]]$X}}{ \eqn{n_i}*p by nvar design matrix for ith unit}
    \item{\code{a}}{vector of length ncomp of Dirichlet prior parms (def: rep(5,ncomp))}
    \item{\code{deltabar}}{nz*nvar vector of prior means (def: 0)}
    \item{\code{Ad}}{ prior prec matrix for vec(D) (def: .01I)}
    \item{\code{mubar}}{ nvar x 1 prior mean vector for normal comp mean (def: 0)}
    \item{\code{Amu}}{ prior precision for normal comp mean (def: .01I)}
    \item{\code{nu}}{ d.f. parm for IW prior on norm comp Sigma (def: nvar+3)}
    \item{\code{V}}{ pds location parm for IW prior on norm comp Sigma (def: nuI)}
    \item{\code{ncomp}}{ number of components used in normal mixture }
    \item{\code{s}}{ scaling parm for RW Metropolis (def: 2.93/sqrt(nvar))}
    \item{\code{w}}{ fractional likelihood weighting parm (def: .1)}
    \item{\code{R}}{ number of MCMC draws}
    \item{\code{keep}}{ MCMC thinning parm: keep every keepth draw (def: 1)}
    \item{\code{chains}}{ number of MCMC simulation chains for \code{CODA} diagnostics}
    \item{\code{output}}{ supported binary output format:
                \code{default}, \code{bayesm}, or \code{coda}.}
  }
}
\value{
For \code{default} format:  a list containing
  \item{llkdraw}{R/keep array of log likelikelhood of draws}
  \item{betadraw}{R/keep x nvar x nlgt array of draws of betas}
  \item{Deltadraw}{R/keep x nvar x nz array of Delta draws, first row is initial value}
  \item{probdraw}{R/keep x ncomp array of draws of probs of mixture components}
  \item{mudraw}{R/keep x nvar x ncomp array of draws of mean parameter of beta coefficients}
  \item{rootdraw}{R/keep x nvar x nvar x ncomp array of error variances of beta coefficients}
  \cr
For \code{bayesm} format:  a list containing
  \item{Deltadraw}{R/keep  x nz*nvar matrix of draws of Delta, first row is initial value}
  \item{betadraw}{ nlgt x nvar x R/keep array of draws of betas}
  \item{nmix}{ list of 3 components, probdraw, NULL, compdraw }
  \item{loglike}{ log-likelihood for each kept draw (length R/keep)}
  \cr
For \code{CODA} output format:
  A list of CODA compatible simulation chains in default format.
}
\note{
  More on \code{probdraw} component of nmix list in \code{bayesm} output format:\cr 
  R/keep x ncomp matrix of draws of probs of mixture components (pvec)  \cr
  More on \code{compdraw} component of return value list: \cr
  \itemize{
  \item{compdraw[[i]]}{ the ith draw of components for mixtures}
  \item{compdraw[[i]][[j]]}{ ith draw of the jth normal mixture comp}
  \item{compdraw[[i]][[j]][[1]]}{ ith draw of jth normal mixture comp mean vector}
  \item{compdraw[[i]][[j]][[2]]}{ ith draw of jth normal mixture cov parm (rooti) }
  }

  Note: Z should \strong{not} include an intercept and is centered for ease of interpretation.\cr
  
  Be careful in assessing prior parameter, Amu.  .01 is too small for many applications. See 
  Rossi et al, chapter 5 for full discussion.\cr

  Note: as of version 2.0-2 of \code{bayesm}, the fractional weight parameter has been changed
  to a weight between 0 and 1.  w is the fractional weight on the normalized pooled likelihood.
  This differs from what is in Rossi et al chapter 5, i.e.

  \eqn{like_i^(1-w) x like_pooled^((n_i/N)*w)}

 
  Large R values may be required (>20,000).
} 
\references{ 
  Rossi, Allenby and McCulloch:\cr
  \emph{Bayesian Statistics and Marketing} Ch 5\cr
  \url{http://www.perossi.org/home/bsm-1}
}
\author{
  Chi Yau (based on R doc of \code{rhierMnlRwMixture} in \code{bayesm} by Peter Rossi)\cr
  \email{chi.yau@r-tutor.com}
}
  
\examples{
\dontrun{

library(rpud)
data.path <- file.path(path.package(package="rpud"), "runit/data")

# load p, Delta, Z, and simlgtdata
load(file.path(data.path, "rhierMnl-n2x6x5-rd.txt.gz")) 

## set parms for priors and Z
R <- 5000
keep <- 5 
seed <- 66

Prior <- list(ncomp=4)
Mcmc <- list(R=R, keep=keep)
Data <- list(p=p, lgtdata=simlgtdata, Z=Z)

set.seed(seed)

system.time(
out <- rpud::rhierMnlRwMixture(
        Data=Data, 
        Prior=Prior, 
        Mcmc=Mcmc, 
        output="bayesm"
))

library(bayesm)

cat("Summary of Delta draws", fill=TRUE)
summary(out$Deltadraw, tvalues=as.vector(Delta))

cat("Summary of Normal Mixture Distribution", fill=TRUE)
summary(out$nmix)

if(0) {
    ## plotting examples
    plot(out$betadraw)
    plot(out$nmix)
}

}}

\keyword{models}
